#!/bin/bash

# Variables added for registry
CP_VER="%%CP_VER%%" ; export CP_VER
SP_VER="%%SP_VER%%" ; export SP_VER
MSP="%%MSP%%" ; export MSP
VER="%%VER%%" ; export VER
PKG_NAME="%%XI_Prod_Name%%" ; export PKG_NAME
MODULE="sho_wrapper" # name of RPM
SHODIR="/opt/CPSharedObjects"
REG_NAME="sho_wrapper" # name in registry/cpinfo
CPPROD_UTIL=${CPDIR}/bin/cpprod_util
XINSTALL=${CPDIR}/bin/XInstall
##########################

SED=/bin/sed
DATE=/bin/date
READLINK=/usr/bin/readlink
DIRNAME=dirname
BASENAME=basename

SCRIPT_DIR=`${DIRNAME} "$0"`
SCRIPT_NAME=`${BASENAME} "$0"`
. $SCRIPT_DIR/sho_log.sh >> /dev/null

log_op "LOG" "----- `${DATE}` -----"
log_op "LOG" "start $SCRIPT_NAME"

log_op "LOG" "Set umask 007 for this session"
umask 007

PATH=""
log_op "LOG" "Activate profile"
cpprofile_path="/opt/CPshared/5.0/tmp/.CPprofile.sh"
if [ -f "$cpprofile_path" ] ; then
    . $cpprofile_path
else
    log_op "ERROR" "***********************************************************"
    log_op "ERROR" "Can not find /opt/CPshared/5.0/tmp/.CPprofile.sh file"
    log_op "ERROR" "Aborting installation..."
    log_op "ERROR" "***********************************************************"
    log_op "ERROR" ""
    log_op "ERROR" "File not found: /opt/CPshared/5.0/tmp/.CPprofile.sh, Exiting!!"
    exit 1
fi



# Set environment variables in .sh cpprofile file
$CAT >> ${CPDIR}/tmp/.CPprofile.sh << EOF
SHODIR=${SHODIR} ; export SHODIR
PATH=\${PATH}:\${SHODIR}/bin ; export PATH ; hash 1>/dev/null 2>&1
EOF

# Set environment variables in .csh cpprofile file
$CAT >> ${CPDIR}/tmp/.CPprofile.csh << EOF
setenv SHODIR "${SHODIR}"
setenv PATH "\${PATH}:\${SHODIR}/bin"
EOF

log_op "LOG" "Adding keys to Check Point registry"

## Because this product is unversioned we need to take CP, MSP and SP from other versioned product
CP_VER=`$CPPROD_UTIL CPPROD_GetCurrentVersion SecurePlatform | $SED 's/ //g' | $SED 's/[^0-9]*//'`
MSP=`$CPPROD_UTIL CPPROD_GetCurrentMSP SecurePlatform | $SED 's/ //g' | $SED 's/[^0-9]*//'`
SP_VER=`$CPPROD_UTIL CPPROD_GetCurrentServicePack SecurePlatform | $SED 's/ //g' | $SED 's/[^0-9]*//'`

PrevMSP=`$CPPROD_UTIL CPPROD_GetCurrentMSP $REG_NAME | $SED 's/ //g' | $SED 's/[^0-9]*//'`
PSP=`$CPPROD_UTIL CPPROD_GetCurrentServicePack $REG_NAME | $SED 's/ //g' | $SED 's/[^0-9]*//'`
PSP=${PSP:-0}
UPGRADE_50=`$CPPROD_UTIL CPPROD_GetValue Products $REG_NAME 0 | $SED 's/ //g'`
if [ "$UPGRADE_50" = "1" ] ; then
    OLD_PRODUCTDIR=`$CPPROD_UTIL CPPROD_GetValue $MODULE PRODUCTDIR 1  | $SED 's/ //g'`
    PROD_ACTIVE=`$CPPROD_UTIL CPPROD_GetValue $MODULE ProdActive 1 | $SED 's/ //g'`
    log_op "LOG" "$PKG_NAME UPGRADE"
    log_op "LOG" " Upgrade Registry"
    $XINSTALL UpgradeRegistry $REG_NAME $SHODIR $CP_VER $SP_VER $MSP 1>/dev/null 2>&1
fi

$XINSTALL CreateRegistry $REG_NAME PRODUCTDIR $SHODIR $VER $CP_VER $SP_VER $MSP 1	1>/dev/null 2>&1

if [ "$UPGRADE_50" = "1" ] ; then
    $CPPROD_UTIL CPPROD_SetValue $MODULE OLD_PRODUCTDIR 1 $OLD_PRODUCTDIR 1  1>/dev/null 2>&1
    $XINSTALL CPstartInRegistry $REG_NAME 1 1 ${PROD_ACTIVE-0} 1>/dev/null 2>&1
else
    $XINSTALL CPstartInRegistry $REG_NAME 1 1 0 1>/dev/null 2>&1
fi

$CPPROD_UTIL CPPROD_SetConfigured $REG_NAME//$CP_VER 1>/dev/null 2>&1
$CPPROD_UTIL CPPROD_SetValue $REG_NAME CurrentVersion 1 $CP_VER 0 1>/dev/null 2>&1

# Clear old hotfixes registry values
$CPDIR/bin/ckp_regedit -d //SOFTWARE//CheckPoint//$REG_NAME//$CP_VER//HotFixes 1>/dev/null 2>&1

# Update install source as AutoUpdater
$CPPROD_UTIL CPPROD_SetValue $REG_NAME//$CP_VER "InstallSource" 1 "AutoUpdater" 0 1>/dev/null 2>&1


log_op "SUCCESS" "Finish running $SCRIPT_NAME"

exit 0
