#!/bin/sh

. /opt/CPshared/5.0/tmp/.CPprofile.sh

BASENAME="basename"
DIRNAME="dirname"
DATE="/bin/date"
READLINK="/usr/bin/readlink"
RM="/bin/rm"
SED=/bin/sed
CPPROD_UTIL=${CPDIR}/bin/cpprod_util


SHO_PRODUCT="sho_wrapper"

#exit codes
SUCCESS=0
FAILED_TO_FIND_PROD_DIR=1
FAILED_TO_RUN_REGISTER_SCRIPT=2


SCRIPT_DIR=$(${DIRNAME} "$0")
SCRIPT_NAME=$(${BASENAME} "$0")

. $SCRIPT_DIR/sho_log.sh >> /dev/null

################################################## Functions ##################################################

stop_docker()
{
	res=$(${SHODIR}/scripts/sho_mgmt.sh stop)
	if [ $? -ne 0 ]; then
		log_op "WARN" "Failed to stop docker container: ${res}"
	fi
	log_op "LOG" "Succeeded to stop docker container"
}


uninstall_sho_wrapper()
{
	SHODIR=$(${CPPROD_UTIL} CPPROD_GetProdDir ${SHO_PRODUCT} | ${SED} "s/ //g")
	if [ "${SHODIR}" = "<nil>" ]; then
		log_op "ERROR"	"Failed to find ${SHO_PRODUCT} directory"
		exit $FAILED_TO_FIND_PROD_DIR
	fi

	stop_docker
	remove_directories
	remove_registry
}


restart_docker()
{
	res=$(${SHODIR}/scripts/sho_mgmt.sh force-restart)
	if [ $? -ne 0 ]; then
		log_op "WARN" "Failed to restart docker container"
	fi
	log_op "LOG" "Succeeded to restart docker container"

}


remove_directories()
{
	if [ -e "${SHODIR}" ]; then
		$RM -r "${SHODIR}" > /dev/null
		if [ $? -ne 0 ]; then
			log_op "WARN" "Failed to remove $SHODIR"
		fi
		log_op "LOG" "Succeeded to remove ${SHODIR}"
	fi
}

remove_registry()
{
    # shellcheck disable=SC2039
    CURR_DIR=$($DIRNAME "$($READLINK -f "${BASH_SOURCE[0]}")")
	$BASH "${CURR_DIR}/sho_remove_registry.sh"
    ret=$?
    if [ $ret -eq 0 ]
    then
        log_op "LOG" "Successfully removed product info from machine registry"
    else
        log_op "ERROR" "Failed to removed product info from machine registry, aborting installation..."
        exit $FAILED_TO_RUN_REGISTER_SCRIPT
    fi

}

is_docker_contarner_active()
{
	SHODIR=$(${CPPROD_UTIL} CPPROD_GetProdDir ${SHO_PRODUCT} | ${SED} "s/ //g")
	if [ "${SHODIR}" = "<nil>" ]; then
		log_op "ERROR"	"Failed to find ${SHO_PRODUCT} directory"
		exit $FAILED_TO_FIND_PROD_DIR
	fi
	#check if ProdActive flag set
	prodActive=$(${CPPROD_UTIL} CPPROD_IsProdActive ${SHO_PRODUCT} | ${SED} "s/ //g")
	if [ "${prodActive}" = "1" ]; then
		return 1
	else
		return 0
	fi
}



################################
#	main
################################
log_op "LOG" "----- `${DATE}` -----"
log_op "LOG" "start $SCRIPT_NAME"


if [ -z $VERSION_TO_REVERT ]; then
	log_op "WARN" "VERSION_TO_REVERT variable is not defined. Cannot identify revert version"
	exit $SUCCESS
fi

if [ $VERSION_TO_REVERT -eq 0 ]; then
	uninstall_sho_wrapper
else
	is_docker_contarner_active || restart_docker
fi

log_op "SUCCESS" "Finish running $SCRIPT_NAME"
exit $SUCCESS
